local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.uv.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

local plugins = {
  { "navarasu/onedark.nvim", lazy = true },
  "Mofiqul/vscode.nvim",
  {
    "nvim-lualine/lualine.nvim",
    dependencies = { "nvim-tree/nvim-web-devicons", "majutsushi/tagbar" },
    opts = {
      options = { section_separators = "", component_separators = "" },
      sections = {
        lualine_a = { { "mode", fmt = function(str) return str:sub(1,1) end } },
        lualine_c = {
          { "filename", path = 1 },
          {
            function() return vim.fn["tagbar#currenttag"]("❭ %s", "", "f") end,
            padding = { left = 0 },
          },
        },
        lualine_x = {
          { "filetype", icon = { align = "right" } },
          { "encoding", padding = { right = 0 } }, "fileformat",
        },
      },
      tabline = {
        lualine_a = { { "buffers", max_length = vim.o.columns, show_filename_only = false } },
      },
    },
  },

  "neovim/nvim-lspconfig",
  {
    "hrsh7th/nvim-cmp",
    dependencies = {
      "hrsh7th/cmp-nvim-lsp",
      "hrsh7th/cmp-buffer",
      "hrsh7th/cmp-path",
      "onsails/lspkind-nvim",
    },
  },
  { "williamboman/mason-lspconfig.nvim", dependencies = { "williamboman/mason.nvim" } },

  "nvim-treesitter/nvim-treesitter",
  "nvim-treesitter/nvim-treesitter-textobjects",
  "nvim-treesitter/nvim-treesitter-context",
}

local opts = {
  root = vim.fn.stdpath("data") .. "/site/pack/lazy/start",  -- Honor Vim's pack structure
  performance = { reset_packpath = false },  -- Otherwise local plugins within packpaths are withdrawn from rtp
}

require("lazy").setup(plugins, opts)
